OC.L10N.register(
    "calendar",
    {
    "Calendar" : "يىلنامە",
    "Today" : "بۈگۈن",
    "Week" : "ھەپتە",
    "Month" : "ئاي",
    "Download" : "چۈشۈر",
    "Delete" : "ئۆچۈر",
    "Share link" : "Share link",
    "New calendar" : "يېڭى يىلنامە",
    "Cancel" : "ۋاز كەچ",
    "Email" : "تورخەت",
    "never" : "ھەرگىز",
    "Repeat" : "قايتىلا",
    "Monday" : "دۈشەنبە",
    "More" : "تېخىمۇ كۆپ",
    "Save" : "ساقلا",
    "Update" : "يېڭىلا",
    "Personal" : "شەخسىي",
    "Attendees" : "قاتناشقۇچىلار",
    "Close" : "ياپ",
    "Location" : "ئورنى",
    "Description" : "چۈشەندۈرۈش",
    "Play" : "چال"
},
"nplurals=1; plural=0;");
